#!/usr/bin/env python

#################################################################################################
# First order of business is always to make all other python modules accessible through the path
#################################################################################################

import sys
import os
import logging
sys.path.append(os.getcwd())

#################################################################################################
# Next, import the tools needed to initialize a data assimilation cycle
#################################################################################################

from da.tools.initexit import start_logger, validate_opts_args, parse_options, CycleControl
from da.tools.pipeline import ensemble_smoother_pipeline
from da.platform.jet import JetPlatForm 
from da.ct.dasystem import CtDaSystem 
from da.ct.statevector import CtStateVector 
from da.ct.obs import CtObservations 
from da.tm5.observationoperator import TM5ObservationOperator 
from da.ct.optimizer import CtOptimizer
from da.tools.pipeline import header, footer


#################################################################################################
# Parse and validate the command line options, start logging
#################################################################################################

start_logger()
opts, args = validate_opts_args(parse_options())

#################################################################################################
# Create the Cycle Control object for this job    
#################################################################################################

DaCycle = CycleControl(opts, args)

PlatForm = JetPlatForm()
DaSystem = CtDaSystem(DaCycle['da.system.rc'])
ObsOperator = TM5ObservationOperator(DaCycle['da.obsoperator.rc'])
Samples = CtObservations()
StateVector = CtStateVector()
Optimizer = CtOptimizer()

##########################################################################################
################### ENTER THE PIPELINE WITH THE OBJECTS PASSED BY THE USER ###############
##########################################################################################


logging.info(header + "Entering Pipeline " + footer) 

ensemble_smoother_pipeline(DaCycle, PlatForm, DaSystem, Samples, StateVector, ObsOperator, Optimizer)


##########################################################################################
################### All done
##########################################################################################

